#!/bin/sh


cd "$SOURCE_DIR"

PRODUCT_NAME="dateloom"

echo "getting build number"
BUILD=`/usr/bin/svn info | grep '^Revision:' | sed 's/^.* //'`
echo "build number is: $BUILD"

echo ""
echo "getting version"
READABLE_VERSION=`sed -n -e '/CFBundleShortVersionString/ {' -e 'n' -e 's/	*<string>//' -e 's/<\/.*//' -e 'p' -e '}' < Resources/info.plist`
VERSION=`sed -n -e '/CFBundleVersion/ {' -e 'n' -e 's/	*<string>//' -e 's/<\/.*//' -e 'p' -e '}' < Resources/info.plist`
echo "readable version: $READABLE_VERSION"
echo "version: $VERSION"

FILENAME=`echo "$VERSION" | tr ' ' _  | tr '(' _  | tr  -d ')'  `
echo "filename: $FILENAME"


echo ""
echo "getting publish date"
DATE=`date`
echo "date: $DATE"

echo ""
echo "getting proj name"
#READABLE_NAME="$PROJECT_NAME"
READABLE_NAME="DateLoom"
#NAME=`echo $PROJECT_NAME | tr A-Z a-z`
NAME=`echo "DateLoom" | tr A-Z a-z`
echo "readable name: $READABLE_NAME"
echo "name: $NAME"


echo ""
echo "getting appcast name"
APPCAST_NAME="appcast.xml"
echo "appcast name: $APPCAST_NAME"


echo ""
echo "Building appcast file"

cat Resources/Sparkle/appcast.template.xml \
| sed "s/%readable_name%/$READABLE_NAME/g" \
| sed "s/%name%/$NAME/g" \
| sed "s/%build%/$BUILD/g" \
| sed "s/%filename%/$FILENAME/g" \
| sed "s/%readable_version%/$READABLE_VERSION/g" \
| sed "s/%version%/$VERSION/g" \
| sed "s/%date%/$DATE/g" \
| sed "s/%size%/$SIZE/g" \
> "$TARGET_TEMP_DIR/$APPCAST_NAME"
if [ -f "$TARGET_TEMP_DIR/$APPCAST_NAME" ];
then
	echo "------------------------------------------------------------"
	cat "$TARGET_TEMP_DIR/$APPCAST_NAME"
	echo "------------------------------------------------------------"
else
	echo "Error: failed to create appcast."
	exit 1
fi

APPCAST_DIR="$SRCROOT/appcast"

echo "removing previous appcast folder"
/bin/rm -Rf "$APPCAST_DIR/$PRODUCT_NAME"


echo "$APPCAST_DIR/$PRODUCT_NAME doesnt exist.  Creating it"

/bin/mkdir "$APPCAST_DIR/$PRODUCT_NAME"


if [ -d "$APPCAST_DIR/$PRODUCT_NAME" ];
then
	echo "New appcast directory ok."
else
	echo "Error: could not create new appcast directory: $APPCAST_DIR/$PRODUCT_NAME"
	exit 1
fi




echo ""
echo "copy the appcast back into the source's appcast directory"
/bin/cp -Rf "$TARGET_TEMP_DIR/appcast.xml" "$APPCAST_DIR/$PRODUCT_NAME/appcast.xml"
if [ -f "$APPCAST_DIR/$PRODUCT_NAME/appcast.xml" ];
then
	echo "Appcast copied to appcast directory successfully"
	
else
	echo "Error:  failed to copy appcast to appcast directory"
	exit 1
fi



echo ""
echo "copy the release notes back into the source's appcast directory"
/bin/cp -Rf "Resources/Sparkle/ReleaseNotes" "$APPCAST_DIR/$PRODUCT_NAME/release_notes_$FILENAME"
# also delete the svn directory here so that it doesn't mess with revision control
/bin/rm -Rf "$APPCAST_DIR/$PRODUCT_NAME/release_notes_$FILENAME/.svn"
if [ -d "$APPCAST_DIR/$PRODUCT_NAME/release_notes_$FILENAME" ];
then
	echo "Release notes coppied to appcast directory successfully"
else
	echo "Error:  failed to copy release notes to appcast directory"
	exit 1
fi


/bin/rm -Rf "$APPCAST_DIR/Appcast"


exit 0
